import { 
  select, 
  csv, 
  scaleLinear,  
  scaleTime,
  area,
  curveBasis,
  extent,
  format,
  max,
  axisLeft, 
  axisBottom,
} from 'd3'

const svg = select("svg");

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Population according to time'
  const xValue = d => d.year; 
  const xAxisLabel = 'Time'
  const yValue = d => d.population; 
  const yAxisLabel = 'Population'

  const margin = { top: 60, right: 40, bottom: 88, left: 150 } 
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  const circleRadius = 10
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice()
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left}, ${margin.top})`)
  
  const yAxisTickFormat = number => 
    format('.1s')(number)
      .replace('G', 'B');
  const xAxis = axisBottom(xScale)
    .ticks(6)
    .tickSize(-innerHeight)
    .tickPadding(15)
  
  const yAxis = axisLeft(yScale)
    .tickFormat(yAxisTickFormat)
    .tickSize(-innerWidth)
    .tickPadding(10) 
  
  const yAxisG =	g.append('g').call(yAxis)
  yAxisG.selectAll('.domain').remove()

  yAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', -93)
    .attr('x', -innerHeight / 2)	
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
    .text(yAxisLabel)
  
	const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0, ${innerHeight})`)
    
  xAxisG.select('.domain').remove()    

  xAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('x', innerWidth / 2)	
    .attr('fill', 'black')
    .text(xAxisLabel)
  
  const areaGenerator = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScale(yValue(d)))
    .curve(curveBasis);
  
  g.append('path')
    .attr('class', 'line-path')
    .attr('d', areaGenerator(data))
  
  svg.append('text')
    .attr('x', width / 2)
    .attr('class', 'title')
    .text(title)
    .attr('y', 45)
};

csv('https://gist.githubusercontent.com/Saiipriiya/250ef910db780a586784e768aa0cd874/raw/bc4033ed73d14f039432d76359fdd99569f852d1/population.csv')
  .then(data => {
  data.forEach(d => {
    d.population = +d.population
    d.year = new Date(d.year)
  });
  render(data);
});